@@ -47,6 +47,58 @@ class ActivityService:
         """
         return self.__client.call("eleme.activity.coupon.queryReceivedCouponDetails", {"shopId": shop_id, "couponActivityId": coupon_activity_id, "couponStatus": coupon_status, "pageNo": page_no, "pageSize": page_size})
 
+    def query_invited_food_activities(self, shop_id):
+        """
+        通过店铺Id查询该店铺被邀约的美食活动
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.activity.food.queryInvitedFoodActivities", {"shopId": shop_id})
+
+    def apply_food_activity(self, activity_id, activity_apply_info):
+        """
+        报名美食活动
+        :param activityId:活动Id
+        :param activityApplyInfo:活动报名信息
+        """
+        return self.__client.call("eleme.activity.food.applyFoodActivity", {"activityId": activity_id, "activityApplyInfo": activity_apply_info})
+
+    def query_food_activities(self, activity_id, shop_id, page_no, page_size):
+        """
+        通过店铺Id和活动Id分页查询店铺已报名的美食活动
+        :param activityId:活动Id
+        :param shopId:店铺Id
+        :param pageNo:页码
+        :param pageSize:每页数量
+        """
+        return self.__client.call("eleme.activity.food.queryFoodActivities", {"activityId": activity_id, "shopId": shop_id, "pageNo": page_no, "pageSize": page_size})
+
+    def update_food_activity_item_stock(self, activity_id, shop_id, item_id, stock):
+        """
+        修改美食活动的菜品库存
+        :param activityId:活动Id
+        :param shopId:店铺Id
+        :param itemId:菜品Id
+        :param stock:库存
+        """
+        return self.__client.call("eleme.activity.food.updateFoodActivityItemStock", {"activityId": activity_id, "shopId": shop_id, "itemId": item_id, "stock": stock})
+
+    def offline_food_activity_item(self, activity_id, shop_id, item_id):
+        """
+        取消参与了美食活动的菜品
+        :param activityId:活动Id
+        :param shopId:店铺Id
+        :param itemId:菜品Id
+        """
+        return self.__client.call("eleme.activity.food.offlineFoodActivityItem", {"activityId": activity_id, "shopId": shop_id, "itemId": item_id})
+
+    def unbind_food_activity(self, activity_id, shop_id):
+        """
+        作废店铺与美食活动的关联关系
+        :param activityId:活动Id
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.activity.food.unbindFoodActivity", {"activityId": activity_id, "shopId": shop_id})
+
     def get_invited_activity_infos(self, shop_id):
         """
         查询店铺邀约活动信息
